package top.qaqaq.dao;

import top.qaqaq.pojo.Book;

import java.util.List;

/**
 * @author RichieZhang
 * @create 2022-12-10 下午 5:36
 */
public interface BookDao {

    /**
     * 添加图书
     * @param book
     * @return
     */
    public int addBook(Book book);

    /**
     * 根据图书id删除图书
     * @param id
     * @return
     */
    public int deleteBookById(Integer id);

    /**
     * 根据图书id更新图书
     * @param book
     * @return
     */
    public int updateBook(Book book);

    /**
     * 根据图书id查询图书
     * @param id
     * @return
     */
    public Book queryBookById(Integer id);

    /**
     * 查询全部图书
     * @return
     */
    public List<Book> queryBooks();

    /**
     * 查询总记录数
     * @return
     */
    Integer queryForPageTotalCount();

    /**
     * 遍历当前页数据
     * @param begin
     * @param pageSize
     * @return
     */
    List<Book> queryForPageItems(int begin, int pageSize);

    /**
     * 按价格区间查询总记录数
     * @param min
     * @param max
     * @return
     */
    Integer queryForPageTotalCountByPrice(int min, int max);

    /**
     * 按价格区间遍历当前页数据
     * @param begin
     * @param pageSize
     * @param min
     * @param max
     * @return
     */
    List<Book> queryForPageItemsByPrice(int begin, int pageSize, int min, int max);
}
